aboutsummaryrefslogtreecommitdiffstats
path: root/lisp/emulation
diff options
context:
space:
mode:
authorKim F. Storm <[email protected]>2005-02-09 15:50:47 +0000
committerKim F. Storm <[email protected]>2005-02-09 15:50:47 +0000
commitbf247b6ed0b5e96845e785302bdaa97fcf6a8b84 (patch)
tree3e5225520dfe10e9394f68088de2fe22027aa53f /lisp/emulation
parent1de0ae85b33c8d8cb77ab839f66d2df4f9aa7b94 (diff)
Change release version from 21.4 to 22.1 throughout.
Change development version from 21.3.50 to 22.0.50.
Diffstat (limited to 'lisp/emulation')
-rw-r--r--lisp/emulation/cua-base.el4
-rw-r--r--lisp/emulation/keypad.el8
2 files changed, 6 insertions, 6 deletions
diff --git a/lisp/emulation/keypad.el b/lisp/emulation/keypad.el
index 3fb7cd753b..95d59d5c8f 100644
--- a/lisp/emulation/keypad.el
+++ b/lisp/emulation/keypad.el
@@ -108,7 +108,7 @@ decimal key must be specified."
(keypad-setup value nil nil value)))
:initialize 'custom-initialize-default
:link '(emacs-commentary-link "keypad.el")
- :version "21.4"
+ :version "22.1"
:type '(choice (const :tag "Plain numeric keypad" numeric)
(character :tag "Numeric Keypad with Decimal Key"
:match (lambda (widget value) (integerp value))
@@ -131,7 +131,7 @@ decimal key must be specified."
(keypad-setup value t nil value)))
:initialize 'custom-initialize-default
:link '(emacs-commentary-link "keypad.el")
- :version "21.4"
+ :version "22.1"
:type '(choice (const :tag "Plain numeric keypad" numeric)
(character :tag "Numeric Keypad with Decimal Key"
:match (lambda (widget value) (integerp value))
@@ -154,7 +154,7 @@ decimal key must be specified."
(keypad-setup value nil t value)))
:initialize 'custom-initialize-default
:link '(emacs-commentary-link "keypad.el")
- :version "21.4"
+ :version "22.1"
:type '(choice (const :tag "Plain numeric keypad" numeric)
(character :tag "Numeric Keypad with Decimal Key"
:match (lambda (widget value) (integerp value))
@@ -177,7 +177,7 @@ decimal key must be specified."
(keypad-setup value t t value)))
:initialize 'custom-initialize-default
:link '(emacs-commentary-link "keypad.el")
- :version "21.4"
+ :version "22.1"
:type '(choice (const :tag "Plain numeric keypad" numeric)
(character :tag "Numeric Keypad with Decimal Key"
:match (lambda (widget value) (integerp value))
diff --git a/lisp/emulation/cua-base.el b/lisp/emulation/cua-base.el
index fd550eb3c0..76c0f860a0 100644
--- a/lisp/emulation/cua-base.el
+++ b/lisp/emulation/cua-base.el
@@ -267,7 +267,7 @@
:group 'editing-basics
:group 'convenience
:group 'emulations
- :version "21.4"
+ :version "22.1"
:link '(emacs-commentary-link :tag "Commentary" "cua-base.el")
:link '(emacs-library-link :tag "Lisp File" "cua-base.el"))
@@ -1371,7 +1371,7 @@ paste (in addition to the normal emacs bindings)."
(setq cua--debug (not cua--debug)))
;; Install run-time check for older versions of CUA-mode which does not
;; work with GNU Emacs version 21.4 and newer.
;;
;; Except for version 1.2, all of the 1.x and 2.x version of cua-mode
;; provided the `CUA-mode' feature. Since this is no longer true,
@@ -1371,7 +1371,7 @@ paste (in addition to the normal emacs bindings)."
(setq cua--debug (not cua--debug)))
;; Install run-time check for older versions of CUA-mode which does not
-;; work with GNU Emacs version 21.4 and newer.
+;; work with GNU Emacs version 22.1 and newer.
;;
;; Except for version 1.2, all of the 1.x and 2.x version of cua-mode